ajdmom.mdl\_2fsv.cmom
=====================

.. automodule:: ajdmom.mdl_2fsv.cmom

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      b_n
      c_n
      cm
      cmoment_y
      dcm
      dpoly
      dt0
      moment_comb
      poly2num
      sub_v
      vvee_IEI_IEII
   
   

   
   
   

   
   
   



